/*
filename :JoystickTx.C
author : fhn
date : 20-july-2018
MCU  : ATtiny13(A)
*/

#define F_CPU	1000000UL

#define OFF		0
#define ON		1
#define TGL		2 

#define SW		0b00000001
#define bSIG	0b00000010
#define BLKR	0b00000100
#define DELY 1000  //microsenconds

#include <avr/io.h>
#include <util/delay.h>

//========================================================
void initPorts ( )
{
	DDRB = (bSIG|BLKR);
}
//========================================================
void setBlkr ( uint8_t status )
{
	if (status == ON )
		PORTB |= BLKR;
	else if (status == OFF )
		PORTB &= (~BLKR);
	else if (status == TGL )
		PORTB ^= BLKR;
}
//========================================================
void initAdc ( )
{
	ADCSRA |= ( (1 << ADPS2) | (1 << ADEN) );  
}
//=========================================================
int readAdc ( int channelno )
{
	ADMUX =  ( (1<<ADLAR) | (channelno%4));  
	ADCSRA |= (1 << ADSC);
	while (ADCSRA & (1 << ADSC));
	return ADCH;
}
//========================================================================================
void sendCode ( int code )
{
	PORTB &= (~bSIG);
	_delay_us(DELY*5);
	for ( int i=512; i>0; i=i/2 )
	{
		PORTB |= (bSIG);
		_delay_us(DELY);
		PORTB &= (~bSIG);
		if (code & i)  
			_delay_us(DELY*3);
		else 
			_delay_us(DELY);
	}
	PORTB |= (bSIG);
	_delay_us(DELY);
	PORTB &= (~bSIG);
	_delay_us(DELY*5);
}
//========================================================================================
int main ( )
{
	int cod=0;
	uint8_t adcx=0, adcy=0;

	_delay_ms(100);
	initPorts ( );
	_delay_ms(50);
	setBlkr ( ON );
	_delay_ms(100);
	initAdc ( );
	_delay_ms(100);
	readAdc ( 2 );
	_delay_ms(100);
	readAdc ( 3 );
	_delay_ms(100);
	setBlkr ( OFF );

	while ( 1 )
	{
		setBlkr ( ON );
		cod=0;
		adcx = readAdc ( 2 );
		_delay_us(100);
		adcy = readAdc ( 3 );

		if ( adcx<80 )
			cod |= 1;
		else if ( adcx>165 )
			cod |= 2;

		if ( adcy<80 )
			cod |= 4;
		else if ( adcy>165 )
			cod |= 8;
		
		if ( PINB & SW ) //not used
			cod |= 16;

		cod |=  (cod<<5);
		sendCode ( cod );

		_delay_ms ( 25 );
		setBlkr ( OFF );
		_delay_ms ( 75 );
	}

	return 0;
}
